ProfilingData

Struct ProfilingData 

pub struct ProfilingData { /* private fields */ }
Profiling data for a ZKBoo circuit.

Implementations

Source

impl ProfilingData

pub fn state_size(&self) -> Shape

Size of the circuit state, in bytes per Word type.

pub fn gate_counts(&self) -> &GateCounts

Counts of each gate type in the circuit, in number of gates per Word type.

pub fn max_live_wordrefs(&self) -> Shape

Maximum number of live word references at any point during execution, in number of word references per Word type.

pub fn max_cumulative_refcount(&self) -> Shape

Maximum cumulative reference count at any point during execution, in number of word references per Word type.

pub fn max_refcount(&self) -> Shape

Maximum reference count for any individual word reference at any point during execution,

pub fn and_msg_size(&self) -> Shape

Size of AND messages in the response, in bytes per Word type.

pub fn response_data(&self) -> ResponseData

Derives response data from this profiling data.

pub fn views_data(&self) -> ViewsData

Derives views data from this profiling data.

pub fn state_mem_usage(&self) -> MemoryUsage

Memory usage for the circuit state, based on the maximum state size during execution.

pub fn output_mem_usage(&self) -> MemoryUsage

Memory usage for the circuit output, based on the total number of output words.

pub fn wordrefs_mem_usage(&self) -> MemoryUsage

Memory usage for word references, based on the maximum number of live word references and maximum cumulative reference count during execution.

pub fn memory_manager_mem_usage<RC: RefCount>(&self) -> MemoryUsage

Memory usage for the memory manager, based on the maximum state size during execution and the number of reference count updates.

pub fn executor_mem_usage<RC: RefCount>(&self) -> MemoryUsage

Total memory usage for the executor, based on the memory usage of the circuit state, word references, memory manager, and output.

pub fn prover_mem_usage<RC: RefCount>(&self) -> MemoryUsage

Memory usage for the prover, based on the memory usage of the circuit state shares, word references, and memory manager.

pub fn verifier_mem_usage<RC: RefCount>(&self) -> MemoryUsage

Memory usage for the verifier, based on the memory usage of the circuit state shares, word references, and memory manager.