pub struct GateCounts {Show 19 fields
pub input: Shape,
pub alloc: Shape,
pub constant: Shape,
pub from_le_words: Shape,
pub to_le_words: Shape,
pub output: Shape,
pub not: Shape,
pub bitxor: Shape,
pub bitand: Shape,
pub bitxor_const: Shape,
pub bitand_const: Shape,
pub unbounded_shl: Shape,
pub unbounded_shr: Shape,
pub rotate_left: Shape,
pub rotate_right: Shape,
pub reverse_bits: Shape,
pub swap_bytes: Shape,
pub cast: ByWordType<Shape>,
pub carry: Shape,
}Expand description
Structure to track gate counts for all Word types. CompositeWords are counted according to their total number of machine Words.
Fields
input: Shapealloc: Shapeconstant: Shapefrom_le_words: Shapeto_le_words: Shapeoutput: Shapenot: Shapebitxor: Shapebitand: Shapebitxor_const: Shapebitand_const: Shapeunbounded_shl: Shapeunbounded_shr: Shaperotate_left: Shaperotate_right: Shapereverse_bits: Shapeswap_bytes: Shapecast: ByWordType<Shape>carry: ShapeTrait Implementations
Sourceimpl Clone for GateCounts
impl Clone for GateCounts
Sourcefn clone(&self) -> GateCounts
fn clone(&self) -> GateCounts
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GateCounts
impl Debug for GateCounts
Sourceimpl Default for GateCounts
impl Default for GateCounts
Sourcefn default() -> GateCounts
fn default() -> GateCounts
Returns the “default value” for a type. Read more
impl Copy for GateCounts